@@ -505,19 +505,6 @@ def _do_bootstrap(
                 )
 
     click.echo("Finished creating {}.".format(constants.BOOTSTRAP_STACK_NAME))
-    if source_provider == "CodeCommit":
-        with betterboto_client.ClientContextManager("codecommit") as codecommit:
-            response = codecommit.get_repository(repositoryName=repo)
-            clone_url = response.get("repositoryMetadata").get("cloneUrlHttp")
-            clone_command = (
-                "git clone --config 'credential.helper=!aws codecommit credential-helper $@' "
-                "--config 'credential.UseHttpPath=true' {}".format(clone_url)
-            )
-            click.echo(
-                "You need to clone your newly created repo now and will then need to seed it: \n{}".format(
-                    clone_command
-                )
-            )
 
 
 def bootstrap_spoke(
